package Task::MasteringPerl;
use strict;
use warnings;

=encoding utf8

=head1 The build file for Task::MasteringPerl

This build file is a modulino; it works as both a build script and
a module.

To build the distribution, run this file normally:

	% perl Makefile.PL

But, it's more interesting than that. You can load it with C<require>
and call C<arguments> to get the data structure it passes to
C<WriteMakefile>:

	my $package = require '/path/to/Makefile.PL';
	my $arguments = $package->arguments;

Note that C<require>-ing a file makes an entry in C<%INC> for exactly
that name. If you try to C<require> another file with the same name,
even from a different path, C<require> thinks it has already loaded
the file. As such, I recommend you always require the full path to the
file.

The return value of the C<require> is a package name (in this case,
the name of the main module. Use that to call the C<arguments> method.

Even if this distribution needs a higher version of Perl, this bit
only needs v5.8. You can play with the data structure with a primitive
Perl.

=cut

use File::Spec::Functions qw(catfile);

my $module    = __PACKAGE__;
( my $dist = $module ) =~ s/::/-/g;

my $github    = 'https://github.com/briandfoy/task-masteringperl';
my $main_file = catfile( 'lib', split /::/, "$module.pm" );

my %WriteMakefile = (
	'MIN_PERL_VERSION' => '5.010',

	'NAME'	        => $module,
	'ABSTRACT_FROM' => $main_file,
	'VERSION_FROM'  => $main_file,
	'LICENSE'       => 'artistic_2',
	'AUTHOR'        => 'brian d foy <bdfoy@cpan.org>',

	'PREREQ_PM' => {
		'AnyDBM_File' => '0',
		'Apache::PerlRun' => '0',
		'Apache::Perldoc' => '0',
		'Apache::Pod' => '0',
		'App::Smbxfer' => '0',
		'AutoLoader' => '0',
		'AutoSplit' => '0',
		'B::Deobfuscate' => '0',
		'B::Deparse' => '0',
		'Benchmark' => '0',
		'Benchmark::Forking' => '0',
		'BerkeleyDB' => '0',
		'BioPerl' => '0',
		'Bit::Vector' => '0',
		'Business::ISBN' => '0',
		'CGI' => '0',
		'CPAN' => '0',
		'Carp' => '0',
		'Carp::Always' => '0',
		'Clone::Any' => '0',
		'Code::Splice' => '0',
		'Config' => '0',
		'Config::ApacheFile' => '0',
		'Config::IniFiles' => '0',
		'Config::JSON' => '0',
		'Config::Scoped' => '0',
		'ConfigReader::Simple' => '0',
		'Const::Fast' => '0',
		'DBD::CSV' => '0',
		'DBI' => '0',
		'DBI::Profile' => '0',
		'DBI::ProfileDumper' => '0',
		'DBI::ProfileDumper::Apache' => '0',
		'DBM::Deep' => '0',
		'Data::Constraint' => '0',
		'Data::Dump' => '0',
		'Data::Dump::Steamer' => '0',
		'Data::Dump::Streamer' => '0',
		'Data::Dumper' => '0',
		'Data::MessagePack' => '0',
		'Data::Printer' => '0',
		'Devel::Cover' => '0',
		'Devel::DProf' => '0',
		'Devel::Declare' => '0',
		'Devel::MyDebugger' => '0',
		'Devel::NYTProf' => '0',
		'Devel::Peek' => '0',
		'Devel::Size' => '0',
		'Devel::SmallProf' => '0',
		'Devel::Trace' => '0',
		'Devel::ebug' => '0',
		'Devel::ebug::Console' => '0',
		'Devel::hdb' => '0',
		'Devel::ptkdb' => '0',
		'Dumbbench' => '0',
		'Email::Send::SMTP' => '0',
		'Email::Stuff' => '0',
		'Errno' => '0',
		'Error' => '0',
		'Exporter' => '0',
		'ExtUtils::MM_Any' => '0',
		'ExtUtils::MM_Unix' => '0',
		'ExtUtils::MM_Win32' => '0',
		'ExtUtils::MakeMaker' => '0',
		'Fcntl' => '0',
		'File::Find' => '0',
		'File::Find::Closures' => '0',
		'File::Spec' => '0',
		'Getopt::Attribute' => '0',
		'Getopt::Declare' => '0',
		'Getopt::Easy' => '0',
		'Getopt::Long' => '0',
		'Getopt::Lucid' => '0',
		'Getopt::Std' => '0',
		'Git::CPAN::Patch' => '0',
		'Git::Github::Creator' => '0',
		'HTML::Parser' => '0',
		'HTTP::Date' => '0',
		'HTTP::Size' => '0',
		'Hash::AsObject' => '0',
		'Hook::Lex::Wrap' => '0',
		'Hook::LexWrap' => '0',
		'IO::Handle' => '0',
		'IO::Interactive' => '0',
		'IO::Socket::INET' => '0',
		'Image::Info' => '0',
		'JSON' => '0',
		'JSON::PP' => '0',
		'JSON::Rabbit' => '0',
		'JSON::Syck' => '0',
		'List::Util' => '0',
		'Log::Log4perl' => '0',
		'Log::Log4perl::Appender::DBI' => '0',
		'Log::Log4perl::Appender::File' => '0',
		'Log::Log4perl::Layout::PatternLayout' => '0',
		'Mac::PropertyList' => '0',
		'Memoize' => '0',
		'ModPerl::PerlRun' => '0',
		'Module::Build' => '0',
		'Module::NotThere' => '0',
		'Module::Release' => '0',
		'Modulino::Demo' => '0',
		'Net::FTP' => '0',
		'Net::MAC::Vendor' => '0',
		'Net::SMTP' => '0',
		'Netscape::Bookmarks' => '0',
		'Netscape::Bookmarks::Category' => '0',
		'Object::Iterate' => '0',
		'Opcode' => '0',
		'POSIX' => '0',
		'PPI' => '0',
		'Package::Stash' => '0',
		'Package:Stash' => '0',
		'Perl::Critic' => '0',
		'Perl::Critic::DEVELOPER' => '0',
		'Perl::Critic::Lax' => '0',
		'Perl::Critic::Policy' => '0',
		'Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire' => '0',
		'Perl::Tidy' => '0',
		'Pod::Checker' => '0',
		'Pod::Coverage' => '0',
		'Pod::Parser' => '0',
		'Pod::Perldoc' => '0',
		'Pod::Perldoc::BaseTo' => '0',
		'Pod::Perldoc::ToRtf' => '0',
		'Pod::Perldoc::ToText' => '0',
		'Pod::Perldoc::ToToc' => '0',
		'Pod::PseudoPod' => '0',
		'Pod::Simple' => '0',
		'Pod::Simple::Subclassing' => '0',
		'Pod::TOC' => '0',
		'Pod::Webserver' => '0',
		'Regexp::Debugger' => '0',
		'ReturnValue' => '0',
		'Safe' => '0',
		'Scalar::Util' => '0',
		'Sereal' => '0',
		'Sereal::Decoder' => '0',
		'Some::Module' => '0',
		'Storable' => '0',
		'Surveyor::App' => '0',
		'Surveyor::Benchmark::GetDirectoryListing' => '0',
		'Sys::Syslog' => '0',
		'Taint::Util' => '0',
		'Template' => '0',
		'Template::Base' => '0',
		'Template::Exception' => '0',
		'Test::Harness' => '0',
		'Test::Inline' => '0',
		'Test::Manifest' => '0',
		'Test::More' => '0',
		'Test::Output' => '0',
		'Test::Perl::Critic' => '0',
		'Test::Pod' => '0',
		'Test::Pod::Coverage' => '0',
		'Test::Taint' => '0',
		'Text::Template::Simple::IO' => '0',
		'Tie::' => '0',
		'Tie::Array' => '0',
		'Tie::Array::PackedC' => '0',
		'Tie::BoundedInteger' => '0',
		'Tie::Cycle' => '0',
		'Tie::Cycle::Sinewave' => '0',
		'Tie::File::Timestamp' => '0',
		'Tie::Scalar' => '0',
		'Tie::Timely' => '0',
		'Tk' => '0',
		'Try::Tiny' => '0',
		'TryCatch' => '0',
		'Vim::Debug' => '0',
		'Win32' => '0',
		'Win32::Registry' => '0',
		'YAML' => '0',
		'YAML::LibYAML' => '0',
		'YAML::Syck' => '0',
		'YAML::Tiny' => '0',
		'YAML::XS' => '0',
		'autodie' => '0',
		'bignum' => '0',
		'constant' => '0',
		'criticism' => '0',
		'diagnostics' => '0',
		'die' => '0',
		'feature' => '0',
		'locale' => '0',
		'overload' => '0',
		'parent' => '0',
		'perlbench' => '0',
		'ptkdb' => '0',
		're' => '0',
		'require' => '0',
		'strict' => '0',
		'warnings' => '0',
		},

	'clean' => { FILES => "$dist-*" },
	);

sub arguments { \%WriteMakefile }

do_it() unless caller;
sub do_it {
	require File::Spec;
	my $MM ='ExtUtils::MakeMaker';
	my $MM_version =
		eval{ "$MM " . $WriteMakefile{'CONFIGURE_REQUIRES'}{'ExtUtils::MakeMaker'} }
			||
		"$MM 6.64";
	eval "use $MM_version; 1" or die "Could not load $MM_version: $@";
	eval "use Test::Manifest 1.21"
		if -e File::Spec->catfile( qw(t test_manifest) );

	my $arguments = arguments();
	my $minimum_perl = $arguments->{MIN_PERL_VERSION} || '5.008';
	eval "require $minimum_perl;" or die $@;

	WriteMakefile( %$arguments );
	}


no warnings;
__PACKAGE__;
